@@ -52,14 +52,14 @@ ResizeImageDialog::ResizeImageDialog(QWidget *parent)
     d->mUpdateFromRatio = false;
     d->mUpdateFromSizeOrPercentage = false;
 
-    auto *mainLayout = new QVBoxLayout;
+    auto mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
     mainLayout->setSizeConstraint(QLayout::SetFixedSize);
 
-    auto *content = new QWidget(this);
+    auto content = new QWidget(this);
     d->setupUi(content);
     mainLayout->addWidget(content);
-    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -86,7 +86,7 @@ ResizeImageDialog::ResizeImageDialog(QWidget *parent)
     connect(d->mHeightPercentSpinBox, &QSpinBox::editingFinished, this, &ResizeImageDialog::slotCalculateImageSize);
     connect(d->mKeepAspectCheckBox, &QCheckBox::toggled, this, &ResizeImageDialog::slotKeepAspectChanged);
 
-    QTimer *timer = new QTimer(this);
+    auto timer = new QTimer(this);
     connect(timer, &QTimer::timeout, this, QOverload<>::of(&ResizeImageDialog::slotCalculateImageSize));
     timer->start(2000);
 }
@@ -105,7 +105,7 @@ void ResizeImageDialog::setOriginalSize(const QSize &size)
     d->mHeightSpinBox->setValue(size.height());
 }
 
-void ResizeImageDialog::setCurrentImageUrl(QUrl imageUrl)
+void ResizeImageDialog::setCurrentImageUrl(const QUrl &imageUrl)
 {
     mCurrentImageUrl = imageUrl;
 
@@ -238,9 +238,11 @@ qint64 ResizeImageDialog::calculateEstimatedImageSize()
         buffer.open(QIODevice::ReadWrite);
         image = image.scaled(size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 
-        if (QString::compare(suffix, "jpg", Qt::CaseInsensitive) == 0 || QString::compare(suffix, "jpeg", Qt::CaseInsensitive) == 0
-            || QString::compare(suffix, "avif", Qt::CaseInsensitive) == 0 || QString::compare(suffix, "heic", Qt::CaseInsensitive) == 0
-            || QString::compare(suffix, "webp", Qt::CaseInsensitive) == 0) {
+        if (QString::compare(suffix, QStringLiteral("jpg"), Qt::CaseInsensitive) == 0
+            || QString::compare(suffix, QStringLiteral("jpeg"), Qt::CaseInsensitive) == 0
+            || QString::compare(suffix, QStringLiteral("avif"), Qt::CaseInsensitive) == 0
+            || QString::compare(suffix, QStringLiteral("heic"), Qt::CaseInsensitive) == 0
+            || QString::compare(suffix, QStringLiteral("webp"), Qt::CaseInsensitive) == 0) {
             image.save(&buffer, suffix.toStdString().c_str(), GwenviewConfig::jPEGQuality());
         } else {
             image.save(&buffer, suffix.toStdString().c_str());
